@@ -31,9 +31,8 @@ pub mod files;
 pub mod multimap;
 pub mod nrs;
 pub mod register;
-pub mod wallet;
 pub use consts::DEFAULT_XORURL_BASE;
-pub use helpers::parse_coins_amount;
+pub use helpers::parse_tokens_amount;
 pub use safe_network::url::*;
 pub use xor_name::{XorName, XOR_NAME_LEN};
 
