@@ -8,9 +8,10 @@
 // Software.
 
 use crate::Safe;
-use anyhow::{Context, Result};
-use rand::{distributions::Alphanumeric, thread_rng, Rng};
-use std::{collections::HashSet, env::var, net::SocketAddr, sync::Once};
+use anyhow::{bail, Context, Result};
+use rand::{distributions::Alphanumeric, rngs::OsRng, thread_rng, Rng};
+use safe_network::types::Keypair;
+use std::{collections::HashSet, env::var, fs, net::SocketAddr, sync::Once};
 use tracing_subscriber::{fmt, EnvFilter};
 
 // Environment variable which can be set with the auth credentials
@@ -21,6 +22,9 @@ const TEST_AUTH_CREDENTIALS: &str = "TEST_AUTH_CREDENTIALS";
 // to be used for all sn_api tests
 const TEST_BOOTSTRAPPING_PEERS: &str = "TEST_BOOTSTRAPPING_PEERS";
 
+// Default file in home directory where bootstrapping contacts are usually found
+const DEFAULT_PEER_FILE_IN_HOME: &str = ".safe/node/node_connection_info.config";
+
 static INIT: Once = Once::new();
 
 // Initialise logger for tests, this is run only once, even if called multiple times.
@@ -40,20 +44,20 @@ pub async fn new_safe_instance() -> Result<Safe> {
     init_logger();
     let mut safe = Safe::default();
     let credentials = match var(TEST_AUTH_CREDENTIALS) {
-        Ok(val) => {
-            let keypair = serde_json::from_str(&val).with_context(|| {
-                format!(
-                    "Failed to parse credentials read from {} env var",
-                    TEST_AUTH_CREDENTIALS
-                )
-            })?;
-            Some(keypair)
+        Ok(val) => serde_json::from_str(&val).with_context(|| {
+            format!(
+                "Failed to parse credentials read from {} env var",
+                TEST_AUTH_CREDENTIALS
+            )
+        })?,
+        Err(_) => {
+            let mut rng = OsRng;
+            Keypair::new_ed25519(&mut rng)
         }
-        Err(_) => None,
     };
 
     let bootstrap_contacts = get_bootstrap_contacts()?;
-    safe.connect(credentials, None, Some(bootstrap_contacts))
+    safe.connect(Some(credentials), None, Some(bootstrap_contacts))
         .await?;
     Ok(safe)
 }
@@ -63,6 +67,35 @@ pub fn random_nrs_name() -> String {
     thread_rng().sample_iter(&Alphanumeric).take(15).collect()
 }
 
+fn read_default_peers_from_file() -> Result<HashSet<SocketAddr>> {
+    let default_peer_file = match dirs_next::home_dir() {
+        None => bail!(
+            "Failed to obtain local home directory where to read {} from",
+            DEFAULT_PEER_FILE_IN_HOME
+        ),
+        Some(mut paths) => {
+            paths.push(DEFAULT_PEER_FILE_IN_HOME);
+            paths.display().to_string()
+        }
+    };
+
+    let raw_json = fs::read_to_string(&default_peer_file).with_context(|| {
+        format!(
+            "Failed to read bootstraping contacts list from file: {}",
+            &default_peer_file
+        )
+    })?;
+    let urls: Vec<String> = serde_json::from_str(&raw_json).with_context(|| {
+        format!(
+            "Failed to parse bootstraping contacts list from file: {}",
+            &default_peer_file
+        )
+    })?;
+    let sockaddrs: Result<HashSet<SocketAddr>, std::net::AddrParseError> =
+        urls.iter().map(|u| u.parse()).collect();
+    Ok(sockaddrs?)
+}
+
 fn get_bootstrap_contacts() -> Result<HashSet<SocketAddr>> {
     let contacts = match var(TEST_BOOTSTRAPPING_PEERS) {
         Ok(val) => serde_json::from_str(&val).with_context(|| {
@@ -72,9 +105,8 @@ fn get_bootstrap_contacts() -> Result<HashSet<SocketAddr>> {
             )
         })?,
         Err(_) => {
-            // we default to this address as that's what we
-            // normally use in local test network as the genesis node address
-            vec!["127.0.0.1:12000".parse()?].into_iter().collect()
+            // read default peers from the file we normally use for peers
+            read_default_peers_from_file()?
         }
     };
 
